@@ -739,9 +739,9 @@ setMethod("intersect.idx",
 
 
 ##' @rdname set_operations
-##' @aliases %in%.nanotime
+##' @method %in% nanotime
 `%in%.nanotime` <- function(x, table) {
-    if (class(table) == "nanoival") {
+    if (inherits(table, "nanoival")) {
         if (is.unsorted(x)) stop("x must be sorted")
         table <- sort(table)
         nanoival_intersect_idx_time_interval_logical_impl(x, table)
@@ -750,15 +750,14 @@ setMethod("intersect.idx",
     }
 }
 
-## ##' @rdname set_operations
-## ##' @aliases %in%,nanotime,nanoival-method
-## setMethod("%in%",
-##           c("nanotime", "nanoival"),
-##           function(x, table) {
-##               if (is.unsorted(x)) stop("x must be sorted")
-##               table <- sort(table)
-##               nanoival_intersect_idx_time_interval_logical_impl(x, table)
-##           })
+##' @rdname set_operations
+setMethod("%in%",
+          c("nanotime", "nanoival"),
+          function(x, table) {
+              if (is.unsorted(x)) stop("x must be sorted")   ## #nocov
+              table <- sort(table)                           ## #nocov
+              nanoival_intersect_idx_time_interval_logical_impl(x, table)  ## #nocov
+          })
 
 ##' @rdname set_operations
 setMethod("intersect",
@@ -819,7 +818,7 @@ setMethod("union",
 setMethod("setdiff",
           c("nanotime", "nanotime"),
           function(x, y) {
-              res <- callNextMethod()
+              res <- if (getRversion() >= "4.5.0") setdiff(as.integer64(x), as.integer64(y)) else callNextMethod()
               oldClass(res) <- "integer64"
               new("nanotime", res)
           })
