@@ -26,10 +26,19 @@ setClass("nanoperiod", contains = "complex")
 ##'
 ##'
 ##'
-##' Adding or subtracting \code{nanoperiod} and \code{nanotime} require a
-##' timezone as third argument. For this reason it is not possible to
-##' use the binary operator `code{+}`. Instead the functions
-##' `\code{plus}` and `\code{minus}` are defined.
+##' Adding or subtracting \code{nanoperiod} and \code{nanotime}
+##' require a timezone as third argument. For this reason it is not
+##' possible to use the binary operator `\code{+}`. Instead the
+##' functions `\code{plus}` and `\code{minus}` are defined. These
+##' functions attempt to keep the same offset within a day in the
+##' specified timezone: this means for instance that adding a day when
+##' that day crosses a time zone adjustment such as a daylight saving
+##' time, results in a true time increment of less or more than 24
+##' hours to preserve the offset. Preserving the offset works for
+##' increments that are smaller than a day too, provided the increment
+##' results in a datetime where the timezone adjustment is valid. When
+##' this is not the case, adding a `nanoperiod` behaves in the same
+##' way as adding a `nanoduration`.
 ##'
 ##'
 ##' @param x,value An object of class \code{nanoperiod}
@@ -731,7 +740,7 @@ NA_nanoperiod_ <- new("nanoperiod", complex(1, -1.0609978954826362e-314, 0))
 ##' @param tz a \code{character} scalar indicating the time zone in which to conduct the rounding
 setMethod("nano_ceiling", c(x="nanotime", precision="nanoperiod"),
           function(x, precision, origin=nanotime(), tz) {
-              if (class(origin) != "nanotime") {
+              if (!inherits(origin, "nanotime")) {
                   stop("'origin' must be of class 'nanotime'")
               }
               if (!is.character(tz)) {
@@ -746,7 +755,7 @@ setMethod("nano_ceiling", c(x="nanotime", precision="nanoperiod"),
 ##' @rdname rounding
 setMethod("nano_floor",   c(x="nanotime", precision="nanoperiod"),
           function(x, precision, origin=nanotime(), tz) {
-              if (class(origin) != "nanotime") {
+              if (!inherits(origin, "nanotime")) {
                   stop("'origin' must be of class 'nanotime'")
               }
               if (!is.character(tz)) {
